use config::Config;
mod cfg;
mod loyalty;
use actix_web::{middleware::Logger, web, App, HttpServer};
use actix_files::Files;


#[actix_web::main]
pub async fn main() -> std::io::Result<()> {

    let settings = Config::builder()
        .add_source(config::File::with_name("settings.yml"))
        .build()
        .unwrap();
    let app: cfg::AppConfig = settings.try_deserialize().unwrap();
    println!(
        "Запуск приложения в режиме {} {}:{}",
        app.debug, app.host, app.port
    );
    env_logger::init_from_env(env_logger::Env::new().default_filter_or("info"));
    log::info!("starting HTTP server at http://{}:{}", app.host, app.port);

    HttpServer::new(|| {
        App::new()
            .app_data(web::Data::new(loyalty::LoyaltyService {
                db: loyalty::db::DbService::new(),
            }))
            .service(loyalty::get_cats)
            .service(loyalty::get_colors)
            .service(loyalty::add_cat)
            .service(loyalty::add_color)
            .service(Files::new("/", "./static/").index_file("index.html"))
    })
    .bind((app.host, app.port))?
    .run()
    .await
}
